@@ -97,7 +97,7 @@ class Thing:
             # If there is a thing id, try to connect
             if self.thing_id is not None:
                 self.token = ThingToken(
-                    private_key_path, self.thing_id, HTTP_API_URI, HTTP_API_URI, algorithm=TOKEN_ALGO)
+                    private_key_path, self.thing_id, self.thing_id, HTTP_API_URI, algorithm=TOKEN_ALGO)
                 self.http = ThingHTTP(self, HTTP_API_URI)
 
                 # Loads all thing's details
